import { FiveRecord, QuestionDialogParameters } from './FiveRecord';
export declare const DeploymentDevelopment = "dev";
export declare const DeploymentTesting = "test";
export declare const DeploymentProduction = "prod";
export interface IDeployment {
    getDeploymentMode(): string;
    getImage(): string;
    getStatus(): string;
    getURL(): string;
}
export interface IClusterManagement {
    calculateDeploymentButtons(deployment: IDeployment, instanceKey: string, classes: any): Array<any>;
    getDeployment(record: FiveRecord | string, mode: string): IDeployment;
    registerForClusterUpdates(callback: (message: string) => void): void;
}
export interface IDataTransactions {
}
export interface IDisplayType {
}
export interface IFormProperties {
}
export interface IFormFieldFormCore {
    /**
     * @hidden
     */
    key(): string;
}
export interface ITable {
}
/** Interface to hold an instance of an Action that has been returned from calling a method of the Five API, or passing into other Five API methods. */
export interface IAction {
    /**
     * @hidden
     */
    key(): string;
    /**
     * @hidden
     */
    actionId(): string;
}
export interface IField {
    /**
     * @hidden
     */
    key(): string;
    /**
     * @hidden
     */
    size(): number;
}
/** Interface to hold an instance of a Plugin that has been returned from calling a method of the Five API, or passing into other Five API methods. */
export interface IPlugin {
}
/**
 * Interface to handle instances of DataManager.
 *
 * Used for internal use only, and is only exposed here for compatibility.
 */
export interface IDataManager {
    /**
     * @hidden
     */
    nameIndex: any;
    getWorkingRecord(): FiveRecord;
}
/** Main Five interface class for accessing infrastructure exported by Five. */
export interface IFive {
    /**
     * The five.stack object contains the properties from the records you've drilled down through, for example parent keys.
     *
     * Example:
     *
     * ```ts
     * SELECT
     *   Client.Name,
     *   Bid.BidAmount
     * FROM
     *   Bid
     * JOIN Auction ON Auction.AuctionKey = Bid.AuctionKey
     * JOIN Client ON Client.ClientKey = Bid.ClientKey
     * WHERE Auction.AuctionKey = '{{five.stack.Auction.AuctionKey}}'
     * ```
     */
    stack: Object;
    /**
     * Returns the selected menu item.
     * @returns
     *
     * Example:
     *
     * ```ts
     * var optionValue = optionIndex[five.getSelectedMenuId()];
     * if (optionValue !== undefined) {
     *     var generalTab = sender.getPage('General');
     *     generalTab.dataManager.setValueByName('ActionType', optionValue);
     *     sender.refresh();
     * }
     * ```
     */
    getSelectedMenuId(): string;
    /**
     * The IFiveSelection object.
     * @returns
     */
    getSelection(): IFiveSelection;
    /**
     * Uploads the data for the document of the given document key to the server
     * @param documentKey Key of the document being uploaded to
     * @param documentData Contents of the file being uploaded
     */
    uploadDocument(documentKey: string, documentData: any): void;
    /**
     * Executes a named function on the Five Application Server.
     * @param name Name of function to call.
     * @param variables Map of variables in the form (name: value) sent to the Five Application Server for processing.
     * @param file A file sent to Five Application Server.
     * @param actionKey Action to execute on the server.
     * @param functionKey Function to execute on the server.
     * @param onResultsCallBack Callback when function has completed on the Five Application Server.
     * @returns
     *
     * **If changing the signature of this function, ensure all other plugins are updated too.**
     *
     * Example:
     *
     * ```ts
     * var five = {};
     * variables = {};
     * variables['quantity'] = 100;
     * variables['supplier'] = 'Toyota';
     * var selectedFile = null;
     * var actionKey = ''; // must contain the actionKey if supplying a functionKey
     * var functionKey = ''; // must contain the function key that you want to execute if not supplying a functionId
     *
     * five.executeFunction('updateStock', variables, selectedFile, actionKey, functionKey, function (result) {
     *     var reply = result.serverResponse;
     *     if (reply.errorCode === 'ErrErrorOk') {
     *         console.log('contains the results from exeute function');
     *     } else {
     *         console.log('problem in the function');
     *     };
     * });
     * ```
     */
    executeFunction(name: string, variables: Map<string, any>, file: File, actionKey: string, functionKey: string, onResultsCallBack: (results: any) => void): void;
    /**
     * Executes the given GraphQL query on the Five Application Server.
     * @param query GraphQL query to be exectued.
     * @param onSuccess Callback when the query has executed and returned from the Five Application Server successfully.
     * @param onFail Callback when the query has executed and returned from the Five Application Server with errors.
     * @returns
     *
     * Example:
     *
     * ```ts
     * const query = `{
     *  dataTypes {
     *   key
     *   name
     *  }
     * }`;
     *
     * five.executeGraphQL(query, (result => {
     *  let dataTypeNameToKey = new Map<string, string>();
     *  const types = result.data.data.dataTypes;
     * });
     * ```
     */
    executeGraphQL(query: string, onSuccess: (result: any) => void, onFail: (result: any) => void): void;
    /**
     * Creates a custom form using the custom form plugin supplied.
     * @param plugin Instance of plugin to create a custom form with, must be a plugin type of Custom Form.
     * @returns
     *
     * Example:
     *
     * ```ts
     *	var plugin = context.getPlugin('formwizard');
     *	context.createCustomForm(plugin);
     *```
     */
    createCustomForm(plugin: IPlugin): void;
    /**
     * Clears the custom form from the display.
     */
    clearCustomForm(): void;
    /**
     * Gets the current local date as a string
     */
    date(): string;
    /**
     * Gets the current local date and time as a string
     */
    dateTime(): string;
    /**
     * Five searches by the name identifier to return a specific instance of the plugin.
     * @param pluginName Name identifier of plugin to retreive.
     * @returns
     *
     * Example:
     *
     * ```ts
     *	var plugin = context.getPlugin('formwizard');
     *	context.createCustomForm(plugin);
     *```
     */
    getPlugin(pluginName: string): IPlugin;
    /**
     * Five searches by the name identifier to return a specific instance of an action.
     * @param name Name identifier of action to retrieve.
     * @returns
     *
     * Example:
     *
     * ```ts
     * var action = five.getAction('Form')
     * ```
     */
    getAction(name: string): IAction;
    /**
     * Five searches by the key identifier to return a specific instance of the action.
     * @param actionKey Key of the action to retrieve.
     * @returns
     */
    getActionByKey(actionKey: string): IAction;
    /**
     * Five searches by the key identifier to return a specific instance of the field.
     * @param fieldKey Key of the field to retrieve.
     * @returns
     */
    getFieldByKey(fieldKey: string): IField;
    /**
     * Gets the table associated with the given action if it exists for that action.
     *
     * Will return Null if table does not exist.
     * @param action The action to retrieve.
     * @returns
     *
     * Example:
     *
     * ```ts
     * var actionTable = five.getActionTable('Charts')
     * ```
     */
    getActionTable(action: IAction): ITable;
    /**
     * Gets a display type by its name.
     * @param name The name of the display type to retrieve.
     * @returns
     *
     * Example:
     *
     * ```ts
     * var displayType = five.getDisplayTypeByName('_Text');
     * ```
     */
    getDisplayTypeByName(name: string): IDisplayType;
    getClusterManager(): IClusterManagement;
    /**
     * Creates a FiveRecord for the given data. This record can be saved using the addRecord and saveRecord functions.
     * @param data A map of fields to values to be turned into a Five Record.
     * @returns
     *
     */
    createRecord(key: string, data: any): FiveRecord;
    /**
     * DEPRECATED
     * Creates the required transaction to add the given record on the given action.
     * @param actionKey Action key of the action to add record for.
     * @param record A FiveRecord holding the record to create the add transaction for.
     * @param dataTransactions
     * @param listId
     * @param parentKey
     */
    createAddTransaction(actionKey: string, record: FiveRecord, dataTransactions: IDataTransactions, listId: string, parentKey: string): void;
    /**
    * DEPRECATED
    * Creates the required transaction to delete the given record on the given action.
    * @param actionKey Action key of the action to delete record for
    * @param record A FiveRecord holding the record to create the delete transaction for
    * @param dataTransactions
    * @param listId
    * @param parentKey
    */
    createDeleteTransaction(actionKey: string, record: FiveRecord, dataTransactions: IDataTransactions, listId: string, parentKey: string): void;
    /**
     * Filter the displayed records by the given key.
     *
     * @param keyName Name of the key to filter by.
     * @param key Value of the key to filter by.
     * @returns
     */
    addFilter(keyName: string, key: string): void;
    /**
     * Add a new record for corresponding action.
     *
     * **NOTE:** The records will be recorded locally and will not be committed and saved to the server until save records is called.
     * @param actionKey Action key of action to add record for.
     * @param record A FiveRecord instance with record data associated with the supplied action.
     * @returns
     *
     * Example:
     *
     * ```ts
     * const key = uuidv1();
     * data[tableKeyName] = key;
     * data[“Manufacturer”] = “Seadoo”;
     * data[“Model”] = “GTX155”;
     *
     *   let record = new FiveRecord(key, "", data);
     *   five.addRecord(action.key(), record);
     * ```
     */
    addRecord(actionKey: string, record: FiveRecord): boolean;
    /**
     * Update an existing record for corresponding action.
     *
     * **NOTE:** The records will be recorded locally and will not be committed and saved to the server until save records is called.
     * @param actionKey Action key of action to add record for.
     * @param record A FiveRecord instance with record data associated with the supplied action.
     * @returns
     *
     * Example:
     *
     * ```ts
     * data[tableKeyName] = existingKeyValue;
     * data[“Manufacturer”] = “Seadoo”;
     * data[“Model”] = “GTX155”;
     *
     *   let record = new FiveRecord(key, "", data);
     *   five.updateRecord(action.key(), record);
     * ```
     */
    updateRecord(actionKey: string, record: FiveRecord): boolean;
    /**
     * Removes a record for the corresponding action.
     * NOTE: The records will be recorded locally and will not be committed and saved to the server until saveRecords is called.
     * @param actionKey Action key of the action to delete record for.
     * @param record A FiveRecord holding the record to be deleted.
     * @returns
     */
    deleteRecord(actionKey: string, record: FiveRecord): boolean;
    /**
     * Updates a record for the corresponding action.
     * NOTE: The records will be recorded locally and will not be committed and saved to the server until saveRecords is called.
     * @param actionKey Action key of the action to update record for.
     * @param record A FiveRecord holding the record to be updated.
     * @returns
     */
    updateRecord(actionKey: string, record: FiveRecord): boolean;
    /**
     * Saves all the transactions that have been added via addRecord.
     * @param onResult Callback with result of saving to the server.
     * @returns
     *
     * Example:
     *
     * ```ts
     * const key = uuidv1();
     * data[tableKeyName] = key;
     * data['Manufacturer'] = 'Seadoo';
     * data['Model'] = 'GTX155';
     *
     *   let record = new FiveRecord(key, '', data);
     *   five.addRecord(action.key(), record);
     *   five.saveRecords
     * ```
     */
    saveRecords(onResult: () => void, onError?: (err: any) => void): void;
    /**
     * Clears all the transactions that have been made via the
     * add/update/delete Record functions
     */
    clearRecords(): void;
    /**
     * @hidden
     */
    getListDataManager(): any;
    /**
     * Generates a Universally Unique ID (UUID)
     */
    uuid(): string;
    /**
     * Show message to the end user.
     * @param message
     */
    message(message: string): void;
    /**
     * Show message to end user with callback on acknowledge
     * @param message the message to be displayed
     * @param callback the function to be run on ok
     */
    alert(message: string, callback: () => void): void;
    question(question: string, onResultsCallBack: (reply: string) => void): void;
    /**
     * Gets the current utc timestamp as a string
     */
    now(): string;
    /**
     * Updates live queries connected to the given tableId
     * @param tableId
     */
    refreshTable(tableId: string): void;
    /**
     * Creates/sets a global variable of the given name with the given value.
     * This variable can be used by queries and other actions.
     * @param name
     * @param value
     */
    setVariable(name: string, value: any): void;
    /**
     * Gets the current local time as a string
     */
    time(): string;
    /**
     * Makes a question dialog pop up on the screen.
     * @param questionParameters QuestionDialogParameters containing the question
     * string, and callback functions for positive and negative actions
     */
    setDialogQuestion(questionParameters: QuestionDialogParameters): void;
    /**
     * Lets Five know that the plugin has modified in some way.
     * @param pluginKey the identifying key of the current plugin
     * @param modified a boolean flag
     */
    setPluginModified(pluginKey: string, modified: boolean): void;
    /**
     * Clears the global variable of the given name.
     * @param name
     */
    clearVariable(name: string): void;
    /**
     * Generates and returns the given form, populated with a given record
     * @param formId
     * @param record
     * @param theme
     * @param onChangeValue
     */
    displayForm(formId: string, record: FiveRecord, theme: any, onDataManagerRefresh: (dataManager: IDataManager) => void, onChangeValue: (value: any, formFieldId: string) => void): any;
    /**
     * Clears the global variable of the given name.
     * @param id the identifying key of the current plugin
     * @param callback the callback function that should get called
     * whenever the plugin is being unmounted from Five
     */
    registerPluginUnmountObserver(id: string, callback: () => void): void;
    /**
    * Validates that the record satisfies the onComplete of the form with the given formId
    * @param formId
    * @param record
    */
    validateCompleteForm(formId: string, record: FiveRecord): boolean;
}
/** Interface to an instance of a form being displayed.*/
export interface IFiveForm {
    /**
     * Id for this particular form.
     * @hidden
     */
    instanceId: string;
    /**
     * Parent form instance.
     * @hidden
     */
    parent: IFiveForm;
    /**
      * Accessing metadata allows you to retrieve more information in the event the form field is a lookup query.
      *
      * The metadata allows reading the save value stored against a form field but can also send other non-defined values using sql to inject extra field parameters.
      *
      * Example:
      *
      * ```ts
      * function OnValidateFormField(sender, context, result) {
      * const form = sender.form;
      * form.FieldId1; // contains the value of FieldId1
      * form.FieldId2; // contains the value of FieldId2
      * form._metadata.FieldId1.value;  // contains the same value as the shorthand version of form.FieldId1
      * form._metadata.FieldId1.extra1; // if FieldId1 is a lookup, optional SQL parameters can be sent to the client to use and inspect.
      * // for example, if form was a customer record, it could be as follows
      * @form.CustomerName;
      * form.Address;
      * form.PostCode; // would produce the postcode itself
      * form._metadata.PostCode.value; // contains the postcode itself as if using form._metadata.PostCode (ie form.PostCode === form._metadata.PostCode.value)
      * form._metadata.PostCode.SuburbName; // could contain the suburb name itself
      * ```
      */
    _metadata: any;
    /**
     * Child form instance.
     * @hidden
     */
    child: IFiveForm;
    /**
     * Action key for this form.
     * @hidden
     */
    actionKey: string;
    /**
     * Holds the current selectedRecord for this form.
     * @hidden
     */
    selectedRecord: FiveRecord;
    /**
     * Tabs associated to this form indexed by key.
     * @hidden
     */
    tabIndex: Map<string, IFivePage>;
    /**
     * Tabs indexed by name.
     * @hidden
     */
    tabIndexByName: Map<string, IFivePage>;
    /**
     * Tabs associated to this form as an array in order.
     * @hidden
     */
    tabs: Array<IFivePage>;
    /**
     * Indicates if this is a new record being created.
     * @hidden
     */
    newRecord: boolean;
    /** Returns the actionKey for the current form.
     * @returns
     */
    getActionKey(): string;
    /**
     * @hidden
     */
    getAction(): IAction;
    /**
     * Returns the parent form.
     * @returns
     *
     * Example:
     *
     * ```ts
     * var parent = five.getParent();
     * ```
     */
    getParent(): IFiveForm;
    /**
     * Returns the top most root form of the forms being displayed.
     * @hidden
     */
    getRootForm(): IFiveForm;
    /**
     * Get page by its name identifier.
     *
     * Will search all children pages until it finds the page by the name identifier.
     * @param name Name of page.
     *
     * ```ts
     * var getPage = five.getPage('General');
     * ```
     */
    getPage(name: string): IFivePage;
    /**
     * DEPRECATED
     * Assembles all variables from the datamanager so they can be sent to the Five Application Server.
     * Currently used by DZSelect. and reactsqleditor
     * @hidden
     */
    assembleVariables(parentVariables: Map<string, any>): void;
    /**
     * Allows a function in Javascript/TypeScript to set variables to be sent to the Five Application Server when requesting or posting a form, or by controls requiring more information.
     * @param name Name of variable.
     * @param value Values of variable.
     * @returns
     */
    setVariable(name: string, value: any): void;
    /**
     * Returns all variables for the entire form and associated sub forms being displayed that will be sent to the server for server processing.
     * @returns A mapping of variables associated to this form in (name: value) pairs.
     */
    getData(): Map<string, any>;
    /**
     * Callback to indicate that this form should force a re-render of itself.
     * @returns
     */
    refresh(): void;
    /**
     * Setting this flag helps the form know that it is a new record, and can make assumptions about how to initialize etc with what values.
     * @param b indicates that this is a new record.
     * @returns
     */
    setIsCreate(b: boolean): void;
    /**
     * Returns a boolean flag indicating if this is a new record being created. (ie not being updated/edited)
     * @returns
     */
    isCreate(): boolean;
    /**
     * Gets a form field by its field name.
     * @param fieldName The field name.
     * @returns
     */
    getValue(fieldName: string): IFormField;
}
/** FivePage instance representing a form page on a form. */
export interface IFivePage {
    /**
     * @hidden
     */
    order: number;
    /** Returns the data manager associated with this FivePage instance.
     * @returns
     *
     * Example:
     *
     * ```ts
     * var getDataManager = fivePage.getDataManager();
     * ```
     */
    getDataManager(): IDataManager;
    /** Returns the caption for this FivePage instance.
     * @returns
     *
     * Example:
     *
     * ```ts
     * var getCaption = fivePage.getCaption();
     * ```
    */
    getCaption(): string;
    /** Returns the key for this FivePage instance.
     * @returns
     *
     * Example:
     *
     * ```ts
     * var getKey = fivePage.getKey();
     * ```
    */
    getKey(): string;
    getFormFields(): Map<string, IFiveField>;
    getFormPage(): any;
    /**Returns the page type for this FivePage instance.
     * @returns
     *
     * Example:
     *
     * ```ts
     * var getTabType = fivePage.getTabType();
     * ```
    */
    getTabType(): string;
    /** Returns the action key assocated with this FivePage instance if it is a page type of List, Sheet, or Table.
     * @returns
     *
     * Example:
     *
     * ```ts
     * var getReferenceActionKey = fivePage.getReferenceActionKey();
     * ```
    */
    getReferenceActionKey(): string;
    /**
     * The parent form containing this form tab.
     * @returns
     *
     * Example:
     * ```ts
     * var getParent = fivePage.getParent();
     * ```
     */
    getParent(): IFiveForm;
    /**
     * Using a field name, find the first occurance of a form field that uses it on the form.
     * @param name Name of field to find a corresponding form field for.
     * @returns
     */
    getField(name: string): IFiveField;
    /**
     * Returns a form page identified by name, this allows querying any lists loaded in the form above the current location.
     * @param name Identifier of form page to find that is currently loaded.
     * @returns
     *
     *
     */
    getParentFormTabByName(name: string): IFivePage;
    /**
     * @hidden
     * @param useThisDataManager
     */
    createFormContext(useThisDataManager: boolean, isCreate: boolean): IFormProperties;
}
/**
 * FiveFormField instance.
 *
 * Represents a form field instance.
 */
export interface IFormField {
    /**
     * Returns the key for the formField.
     */
    key(): string;
    /**
     * Attach a function to be executed when the field is entered.
     * @param sender FormField
     * @param context
     * @param result FiveError that can be updated.
     * @return
     *
     * Example:
     *
     * ```ts
     * function CalculateSubTotal(sender, context, result) {
     *   var form = sender.form;
     *   form.SubTotal = form.Quantity * form.Price * form.GST;
     * }
     * ```
     */
    OnEnter(sender: any, context: any, result: any): void;
    /**
     * Attach a function that will be executed when the form is saved to validate data entry.
     * @param sender FormField
     * @param context
     * @param result Five error that can be updated.
     * @return FiveError
     *
     * Example:
     *
     * ```ts
     * function ValidateMinimumAmount(sender, context, result) {
     *   if(sender.form.MinimumAmount  >= 10) {
     *       return five.Success(result, "Sufficient amount");
     *   }
     *
     *   return five.CreateError(result, "Minimum order placed must be $10.00");
     * }
     * ```
     */
    OnValidate(sender: any, context: any, result: any): any;
    /**
     * Attach a function to be executed upon exiting the form field.
     * @param sender FormField
     * @param context
     * @param result Five error that can be updated.
     * @return
     *
     * Example:
     *
     * ```ts
     *  function CalculateTotal(sender, context, result) {
     *   var form = sender.form;
     *   form.Total = form.SubTotal + form.Delivery;
     * }
     * ```
     */
    OnExit(sender: any, context: any, result: any): void;
}
/**
 * IFiveFormField instance.
 * Represents a form field on a form page.
 */
export interface IFiveField {
    /**
     * Actual concrete form field internal instance.
     * @private
     */
    formField: IFormFieldFormCore;
    /**
     * Returns the current value of this form field.
     * @returns
     *
     * Example:
     * ```ts
     * var getValue = fiveField.getValue();
     * ```
     */
    getValue(): any;
    setDisabled(disabled: boolean): void;
}
/**
 * IFiveSelection instance.
 * Represents a selection on the menu.
 */
export interface IFiveSelection {
    /**
     * Returns the selection from the menu one layer above.
     * @returns
     *
     * Example:
     * ```ts
     * var getParent = fiveSelection.getParent();
     * ```
     */
    getParent(): IFiveSelection;
    /**
     * Returns the name of the menu that the selection is part of.
     * @returns
     *
     * Example:
     * ```ts
     * var getMenuName = fiveSelection.getMenuName();
     * ```
     */
    getMenuName(): string;
    /**
     * Returns the currently selected item in the menu.
     * @returns
     *
     * Example:
     * ```ts
     * var getRecord = fiveSelection.getRecord();
     * ```
     */
    getRecord(): FiveRecord;
}
//# sourceMappingURL=Five.d.ts.map